@@ -1,7 +1,7 @@
 package App::wdq;
 use v5.14;
 
-our $VERSION = '0.1.1';
+our $VERSION = '0.1.2';
 
 1;
 __END__
@@ -42,9 +42,15 @@ the L<wdq> script to some place in your C<$PATH>:
   # get all parts of the solar system
   wdq -q '{ ?c wdt:P361 wd:Q544 }'
 
+  # print expanded SPARQL query 
+  wdq -n -q '{ ?c wdt:P361 wd:Q544 }'
+  
   # execute query and return tab-separated values
   wdq -f tsv < query
 
+  # execute query, abbreviate Wikidata identifier, emit simple JSON
+  wdq -f simple --ids < query
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright Jakob Voss, 2015-
